# fprime-tools

A package containing tools to work with F´. Installation can be done using:

```
pip install fprime-tools
```

See also: https://nasa.github.io/fprime to see the F´ framework.


## Black Formatter

To automatically format code, the Black Formatter can be installed with:
```pip install black```

Then it can be run on the project using:
```
black ./
```